==> pusher-websocket-java-0.1.5-sources.jar: com/pusher/client/Client.java <==
package com.pusher.client;

import com.pusher.client.channel.Channel;
import com.pusher.client.channel.ChannelEventListener;
import com.pusher.client.channel.PresenceChannel;
import com.pusher.client.channel.PresenceChannelEventListener;
import com.pusher.client.channel.PrivateChannel;
import com.pusher.client.channel.PrivateChannelEventListener;
import com.pusher.client.connection.Connection;
import com.pusher.client.connection.ConnectionEventListener;
import com.pusher.client.connection.ConnectionState;

/**
 * Created by jamiepatel on 09/06/2016.
 */
public interface Client {

  Connection getConnection();

  void connect();

  void connect(final ConnectionEventListener eventListener, ConnectionState... connectionStates);

  void disconnect();

  Channel subscribe(final String channelName);

  Channel subscribe(final String channelName, final ChannelEventListener listener, final String... eventNames);

  PrivateChannel subscribePrivate(final String channelName);

  PrivateChannel subscribePrivate(final String channelName, final PrivateChannelEventListener listener,
                                  final String... eventNames);

  PresenceChannel subscribePresence(final String channelName);

  PresenceChannel subscribePresence(final String channelName, final PresenceChannelEventListener listener,
                                    final String... eventNames);

  void unsubscribe(final String channelName);

  Channel getChannel(final String channelName);

  PrivateChannel getPrivateChannel(final String channelName);

  PresenceChannel getPresenceChannel(final String channelName);
}

==> pusher-websocket-java-0.2.0-sources.jar: com/pusher/client/Client.java <==
package com.pusher.client;

import com.pusher.client.channel.Channel;
import com.pusher.client.channel.ChannelEventListener;
import com.pusher.client.channel.PresenceChannel;
import com.pusher.client.channel.PresenceChannelEventListener;
import com.pusher.client.channel.PrivateChannel;
import com.pusher.client.channel.PrivateChannelEventListener;
import com.pusher.client.connection.ConnectionManager;
import com.pusher.client.connection.ConnectionEventListener;
import com.pusher.client.connection.ConnectionState;

/**
 * Created by jamiepatel on 09/06/2016.
 */
public interface Client {

  ConnectionManager getConnectionManager();

  void connect();

  void connect(final ConnectionEventListener eventListener, ConnectionState... connectionStates);

  void disconnect();

  Channel subscribe(final String channelName);

  Channel subscribe(final String channelName, final ChannelEventListener listener, final String... eventNames);

  PrivateChannel subscribePrivate(final String channelName);

  PrivateChannel subscribePrivate(final String channelName, final PrivateChannelEventListener listener,
                                  final String... eventNames);

  PresenceChannel subscribePresence(final String channelName);

  PresenceChannel subscribePresence(final String channelName, final PresenceChannelEventListener listener,
                                    final String... eventNames);

  void unsubscribe(final String channelName);

  Channel getChannel(final String channelName);

  PrivateChannel getPrivateChannel(final String channelName);

  PresenceChannel getPresenceChannel(final String channelName);
}
